#
# spec file for package fish
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fish
Version:        2.3.1
Release:        1.13
Summary:        A user friendly interactive shell
License:        GPL-2.0
Group:          System/Shells
Url:            http://fishshell.com/
Source:         https://github.com/fish-shell/fish-shell/releases/download/%{version}/fish-%{version}.tar.gz 
# PATCH-FIX-UPSTREAM no-return-in-nonvoid-function.patch Fix no-return-in-nonvoid-function error
Patch0:         no-return-in-nonvoid-function.patch
BuildRequires:  autoconf
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  groff
BuildRequires:  ncurses-devel
BuildRequires:  python
Requires:       man
Requires:       python-curses
Recommends:     terminfo
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
fish is a user friendly command line shell for UNIX-like operating systems such as Linux.

It's geared towards interactive use and its features are focused on user friendlieness and
discoverability. The language syntax is simple but incompatible with other shell languages.

%prep
%setup -q
%patch0 -p1

%build
autoconf
%configure
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%find_lang %{name}

%post
# Add fish to the list of allowed shells in /etc/shells
if ! grep %{_bindir}/%{name} %{_sysconfdir}/shells >/dev/null; then
	echo %{_bindir}/%{name} >>%{_sysconfdir}/shells
fi

%postun
# Remove fish from the list of allowed shells in /etc/shells
if [ "$1" = 0 ]; then
	grep -v %{_bindir}/%{name} %{_sysconfdir}/shells >%{_sysconfdir}/%{name}.tmp
	mv %{_sysconfdir}/%{name}.tmp %{_sysconfdir}/shells
fi

%files -f %{name}.lang
%defattr(-,root,root)
%dir /etc/fish
%config(noreplace) %{_sysconfdir}/%{name}/*
%{_bindir}/*
%{_datadir}/doc/%{name}
%{_datadir}/%{name}
%{_datadir}/pkgconfig/fish.pc
%{_mandir}/man1/*

%changelog
* Tue Jul  5 2016 sflees@suse.de
- Update source url to point to github as within the release notes,
  the older url doens't seem available
* Mon Jul  4 2016 sflees@suse.de
- Update to v2.3.1
- Significant changes
  * A new fish_key_reader binary for decoding interactive keypresses (#2991).
  * fish_mode_prompt has been updated to reflect the changes in the way the
    Vi input mode is set up (#3067), making this more reliable.
  * fish_config can now properly be launched from the OS X app bundle (#3140).
- Notable fixes and improvements
  * Extra lines were sometimes inserted into the output under Windows (Cygwin
    and Microsoft Windows Subsystem for Linux) due to TTY timestamps
    not being updated (#2859).
  * The string builtin's match mode now handles the combination of -rnv (match,
    invert and count) correctly (#3098).
  * Improvements to TTY special character handling (#3064), locale handling (#3124)
    and terminal environment variable handling (#3060).
  * Work towards handling the terminal modes for external commands launched
    from initialisation files (#2980).
  * Ease the upgrade path from fish 2.2.0 and before by warning users to restart
    fish if the string builtin is not available (#3057).
  * type -a now syntax-colorizes function source output.
  * Added completions for alsamixer, godoc, gofmt, goimports, gorename, lscpu,
    mkdir, modinfo, netctl-auto, poweroff, termite, udisksctl and xz (#3123).
  * Improved completions for apt (#3097), aura (#3102),git (#3114), npm (#3158),
    string and suspend (#3154).
* Mon May 23 2016 sflees@suse.de
- Update to v2.3.0
- Significant Changes
  * A new string builtin to handle… strings!
  * After seeing an escape character wait up to 300ms for an a
    dditional character.
  * Add new directories for vendor functions and configuration
    snippets (#2498)
  * A new fish_realpath builtin and associated function to allow
    the use of realpath even on those platforms that don't ship
    an appropriate command. (#2932)
  * Alt-# toggles the current command line between commented and
    uncommented states, making it easy to save a command in
    history without executing it.
  * The fish_vi_mode function is now deprecated in favour of
    fish_vi_key_bindings
- Backward-incompatible changes
  * Unmatched globs will now cause an error, except when used
    with for, set or count (#2719, #2394) and and or will now bind
    to the closest if or while, allowing compound conditions without
    begin and end (#1428)
  * set -ql now searches up to function scope for variables (#2502)
  * status -f will now behave the same when run as the main script
    or using source (#2643)
  * source no longer puts the file name in $argv if no arguments
    are given (#139)
- Full release notes at
  https://github.com/fish-shell/fish-shell/releases/tag/2.3.0
* Thu Nov 19 2015 infroma@gmail.com
- Recommends: terminfo (required for some terminals)
- Requires: man (required for completions, otherwise fish complains
  about non existant `apropos` on every TAB)
* Mon Jul 27 2015 develop7@develop7.info
- update to v2.2.0
  See full changelog on
  https://github.com/fish-shell/fish-shell/releases/tag/2.2.0
- Drop check_for_command-not-found_command_on_suse.patch
* Sat Mar 21 2015 simon@simotek.net
- Require: python-curses Its required for the prompt page on
    the web config
* Thu Feb  5 2015 schwab@suse.de
- no-return-in-nonvoid-function.patch: fix no-return-in-nonvoid-function
  error
* Wed Jan 28 2015 zawertun@gmail.com
- Added check_for_command-not-found_command_on_suse.patch
  (https://github.com/fish-shell/fish-shell/issues/1208)
* Mon Dec  1 2014 seanpwatson@live.com
- Fixed conflict with youtube-dl
* Thu Oct  9 2014 seanpwatson@live.com
- update to 2.1.1
- The fish_config web interface now uses an authentication token
  to protect requests and only responds to requests from the local
  machine with this token, preventing a remote code execution
  attack (closing CVE-2014-2914).
- psub and funced are no longer vulnerable to attacks which
  allow local privilege escalation and data tampering (closing
  CVE-2014-2906 and CVE-2014-3856)
- fishd uses a secure path for its socket, preventing a local
  privilege escalation attack (closing CVE-2014-2905)
- __fish_print_packages is no longer vulnerable to attacks which
  would allow local privilege escalation and data tampering
  (closing CVE-2014-3219)
- fishd now ignores SIGPIPE, fixing crashes using tools like
  GNU Parallel and which occurred more often as a result of
  the other fishd changes.
* Sat Oct 12 2013 mailaender@opensuse.org
- update to 2.1.0
- removed rpath patch as it has been resolved upstream
* Sat May 18 2013 mailaender@opensuse.org
- Update to version 2.0
* Sat Mar 28 2009 bitshuffler@opensuse.org
- Initial RPM
